# plugins/youtube_search.py

import logging
import simplematrixbotlib as botlib
from youtube_search import YoutubeSearch

async def handle_command(room, message, bot, PREFIX, config):
    match = botlib.MessageMatch(room, message, bot, PREFIX)
    if match.is_not_from_this_bot() and match.prefix() and match.command("yt"):
        args = match.args()
        if len(args) < 1:
            await bot.api.send_text_message(room.room_id, "Usage: !yt <search terms>")
        else:
            search_terms = " ".join(args)
            logging.info(f"Performing YouTube search for: {search_terms}")
            results = YoutubeSearch(search_terms, max_results=3).to_dict()
            if results:
                output = generate_output(results)
                await send_collapsible_message(room, bot, output)
            else:
                await bot.api.send_text_message(room.room_id, "No results found.")

def generate_output(results):
    output = ""
    for video in results:
        output += f'<a href="https://www.youtube.com/watch?v={video["id"]}">'
        output += f'<img src="{video["thumbnails"][0]}"></img><br>'
        output += f'<strong>{video["title"]}</strong><br>'
        output += f'Length: {video["duration"]} | Views: {video["views"]}<br>'
        if video["long_desc"]:
            output += f'Description: {video["long_desc"]}<br>'
        output += "</a><br>"
    return output


async def send_collapsible_message(room, bot, content):
    message = f'<details><summary><strong>🍄Funguy ▶YouTube Search🍄<br>⤵︎Click Here To See Results⤵︎</strong></summary>{content}</details>'
    await bot.api.send_markdown_message(room.room_id, message)
